// CustomDrawingView.cpp : implementation of the CCustomDrawingView class
//

#include "stdafx.h"
#include "CustomDrawing.h"

#include "CustomDrawingDoc.h"
#include "CustomDrawingView.h"
#include "MyCustomDraw.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CCustomDrawingView

IMPLEMENT_DYNCREATE(CCustomDrawingView, CView)

BEGIN_MESSAGE_MAP(CCustomDrawingView, CView)
    //{{AFX_MSG_MAP(CCustomDrawingView)
    ON_WM_CREATE()
    ON_WM_DESTROY()
    ON_WM_SIZE()
    ON_WM_ERASEBKGND()
    //}}AFX_MSG_MAP
    // Standard printing commands
    ON_COMMAND(ID_FILE_PRINT, CView::OnFilePrint)
    ON_COMMAND(ID_FILE_PRINT_DIRECT, CView::OnFilePrint)
    ON_COMMAND(ID_FILE_PRINT_PREVIEW, CView::OnFilePrintPreview)

    ON_COMMAND(ID_COLLAPSE, CCustomDrawingView::OnCollapse)
    ON_COMMAND(ID_EXPAND, CCustomDrawingView::OnExpand)
    ON_COMMAND(ID_SHOW_LINES, CCustomDrawingView::OnShowLines)
	ON_UPDATE_COMMAND_UI(ID_SHOW_LINES, CCustomDrawingView::OnShowLinesUpdateUI)
    ON_COMMAND(ID_SHOW_COLORS, CCustomDrawingView::OnEnableColoring)
	ON_UPDATE_COMMAND_UI(ID_SHOW_COLORS, CCustomDrawingView::OnEnableColoringUI)
    ON_COMMAND(ID_SHOW_ICONS, CCustomDrawingView::OnEnableIcons)
	ON_UPDATE_COMMAND_UI(ID_SHOW_ICONS, CCustomDrawingView::OnEnableIconsUI)
    ON_COMMAND(ID_SHOW_FIXED_CONTENT, CCustomDrawingView::OnEnableFixedContent)
	ON_UPDATE_COMMAND_UI(ID_SHOW_FIXED_CONTENT, CCustomDrawingView::OnEnableFixedContentUI)
END_MESSAGE_MAP()


/////////////////////////////////////////////////////////////////////////////
// CCustomDrawingView construction/destruction

CCustomDrawingView::CCustomDrawingView() 
   : m_CustomDraw(false)
   , m_Filter(false)
{
    // TODO: add construction code here

}

CCustomDrawingView::~CCustomDrawingView()
{
}

BOOL CCustomDrawingView::PreCreateWindow(CREATESTRUCT& cs)
{
    // TODO: Modify the Window class or styles here by modifying
    //  the CREATESTRUCT cs

    return CView::PreCreateWindow(cs);
}

/////////////////////////////////////////////////////////////////////////////
// CCustomDrawingView drawing

void CCustomDrawingView::OnDraw(CDC* pDC)
{
    CCustomDrawingDoc* pDoc = GetDocument();
    ASSERT_VALID(pDoc);
    // TODO: add draw code for native data here
}

/////////////////////////////////////////////////////////////////////////////
// CCustomDrawingView printing

BOOL CCustomDrawingView::OnPreparePrinting(CPrintInfo* pInfo)
{
    // default preparation
    return DoPreparePrinting(pInfo);
}

void CCustomDrawingView::OnBeginPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
    // TODO: add extra initialization before printing
}

void CCustomDrawingView::OnEndPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
{
    // TODO: add cleanup after printing
}

/////////////////////////////////////////////////////////////////////////////
// CCustomDrawingView diagnostics

#ifdef _DEBUG
void CCustomDrawingView::AssertValid() const
{
    CView::AssertValid();
}

void CCustomDrawingView::Dump(CDumpContext& dc) const
{
    CView::Dump(dc);
}

CCustomDrawingDoc* CCustomDrawingView::GetDocument() // non-debug version is inline
{
    ASSERT(m_pDocument->IsKindOf(RUNTIME_CLASS(CCustomDrawingDoc)));
    return (CCustomDrawingDoc*)m_pDocument;
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CCustomDrawingView message handlers

int CCustomDrawingView::OnCreate(LPCREATESTRUCT lpCreateStruct) 
{
    if (CView::OnCreate(lpCreateStruct) == -1)
        return -1;
    
    m_Grid.Create(0, 0, WS_VISIBLE|WS_CHILD, CRect(0, 0, 0, 0), this, 1000);

	//Set a header
    Dapfor::GUI::CHeader* header = new Dapfor::GUI::CHeader(true);
	header->Add(new Dapfor::GUI::CColumn(COrder::FidProduct,	_T("Product"),	  150, Dapfor::GUI::CColumn::Left));
	header->Add(new Dapfor::GUI::CColumn(COrder::FidUnitPrice,	_T("Unit price"), 80));
	header->Add(new Dapfor::GUI::CColumn(COrder::FidCount,		_T("Count"),	  80, Dapfor::GUI::CColumn::Auto, true));
	header->Add(new Dapfor::GUI::CColumn(COrder::FidPrice,		_T("Price"),	  80));
	header->Add(new Dapfor::GUI::CColumn(COrder::FidTimeStamp , _T("Time"),		  100, Dapfor::GUI::CColumn::Left, true));
	header->Add(new Dapfor::GUI::CColumn(COrder::FidStatus,		_T("Status"),	  100, Dapfor::GUI::CColumn::Left, true));

    m_Grid.SetHeader(header);


	m_Grid.SetCustomDraw(&m_CustomDraw);

    //Add objects from the document to the grid...
	const CCustomDrawingDoc::Orders& orders = GetDocument()->GetOrders();
	int count = orders.size();
	
	//Add some orders in the non-scrollable context and build a small hierarchy...
	CCustomDrawingDoc::Orders::const_iterator it = orders.begin();
	if(it != orders.end())
	{
		//Add a root item
		Dapfor::GUI::HITEM root = m_Grid.Add(*it++ , Dapfor::GUI::GI_FIXED_ROOT);
		m_Grid.Expand(root, false);
		
		//Add 3 orders to the root
		for(int i = 1; i < 4; ++i)
		{
			if(it == orders.end()) break;
			m_Grid.Add(*it++, root);

		}

		//Add remaining orders to the scrollable context
		for(; it != orders.end(); ++it)
		{
			m_Grid.Add(*it);
		}

	}



	//Add the document to the grid
	m_Grid.Add(GetDocument(), Dapfor::GUI::GI_FIXED_ROOT);
	


	//Set a background image
    m_Background.LoadBitmap(IDB_BACKGROUND);
    Dapfor::GUI::CBackgroundImage bi;
    bi.SetBitmap(&m_Background);
	bi.SetMode(Dapfor::GUI::CBackgroundImage::Stretch);
	bi.SetOpacity(125);
	
	m_Grid.SetBackgroundImage(bi);
    
	m_Grid.AllowHighlight(false);
    
	m_Grid.SetFilter(&m_Filter);

    return 0;
}

void CCustomDrawingView::OnDestroy() 
{
	m_Grid.SetCustomDraw(0);
	m_Grid.SetFilter(0);
    CView::OnDestroy();
}

void CCustomDrawingView::OnSize(UINT nType, int cx, int cy) 
{
    CView::OnSize(nType, cx, cy);
    

    //Adjust the grid to client rectangles
    CRect rc;
    GetClientRect(rc);
    m_Grid.MoveWindow(rc);
}

BOOL CCustomDrawingView::OnEraseBkgnd(CDC* pDC) 
{
    //Prevent from erase background
    return TRUE;    
}


void CCustomDrawingView::OnExpand()
{
	m_Grid.Expand(Dapfor::GUI::GI_FIXED_ROOT, true);
}

void CCustomDrawingView::OnCollapse()
{
	m_Grid.Collapse(Dapfor::GUI::GI_FIXED_ROOT, true);
}

void CCustomDrawingView::OnShowLines()
{
    BOOL visible = (m_Grid.GetAppearance().IsVerticalLinesEnabled() || 
		m_Grid.GetAppearance().IsHorizontalLinesEnabled());
	
	
    if(visible)
    {
        //Hide the lines
        m_Grid.GetAppearance().EnableVerticalLines(false);
        m_Grid.GetAppearance().EnableHorizontalLines(false);
    }
    else
    {
        //Show the lines
        m_Grid.GetAppearance().EnableVerticalLines(true);
        m_Grid.GetAppearance().EnableHorizontalLines(true);
    }
    m_Grid.Invalidate(FALSE);
}

void CCustomDrawingView::OnShowLinesUpdateUI(CCmdUI* pCmdUI)
{
    BOOL visible = (m_Grid.GetAppearance().IsVerticalLinesEnabled() || 
		m_Grid.GetAppearance().IsHorizontalLinesEnabled());
	
    pCmdUI->SetCheck(visible);
}

void CCustomDrawingView::OnEnableColoring()
{
	m_CustomDraw.EnableColoring(!m_CustomDraw.IsColoringEnabled());
	m_Grid.Invalidate(FALSE);
}
void CCustomDrawingView::OnEnableColoringUI(CCmdUI* pCmdUI)
{
	pCmdUI->SetCheck(m_CustomDraw.IsColoringEnabled() != 0);
}

void CCustomDrawingView::OnEnableIcons()
{
	m_CustomDraw.EnableIconsPainting(!m_CustomDraw.IsIconsPaintingEnabled());
	m_Grid.Invalidate(FALSE);
}
void CCustomDrawingView::OnEnableIconsUI(CCmdUI* pCmdUI)
{
	pCmdUI->SetCheck(m_CustomDraw.IsIconsPaintingEnabled() != 0);
}

void CCustomDrawingView::OnEnableFixedContent()
{
	m_Filter.ShowFixedContent(!m_Filter.CanShowFixedContent());
	m_Grid.UpdateFilter();
}
void CCustomDrawingView::OnEnableFixedContentUI(CCmdUI* pCmdUI)
{
	pCmdUI->SetCheck(m_Filter.CanShowFixedContent() != 0);
}
