#include "StdAfx.h"
#include "TestClass.h"

#include <Dapfor/Common/LongDateFormat.h>

//Field map implementation. Here you declare the properties of the class that will be accessible from the grid.
//Each property has an unique identifier, and optionally may have a name, Get-function, Set-function and a format 
//to convert value, returned by the Get- function to string and vice-versa.
DF_BEGIN_FIELD_MAP(CTestClass)
    DF_MFC_STRING_ID(FidName, _T("Name"), &CTestClass::GetName, 0, 0)

    //Normally you can't use the same identifier twice. If you uncomment the line below you'll give 
    //'Assertion failed' dialog box. This permits you detect non-obvious errors as soon as possible.
    //DF_LONG_ID(FidName, _T("Long"), &CTestClass::GetSomeLong, 0, 0)

    DF_LONG_ID(FidSomeLong, _T("Long"), &CTestClass::GetSomeLong, &CTestClass::SetSomeLong, 0)
    DF_INT64_ID(FidSomeInt64, _T("Int64"), &CTestClass::GetSomeInt64, &CTestClass::SetSomeInt64, 0)
    DF_DOUBLE_ID(FidSomeDouble, _T("Double"), &CTestClass::GetSomeDouble, &CTestClass::SetSomeDouble, 0)
    
	//This field represents the date
	DF_LONG_ID(FidSomeDate, _T("Date"), &CTestClass::GetSomeDate, &CTestClass::SetSomeDate, new CLongDateFormat(CLongDateFormat::short_date));
DF_END_FIELD_MAP()

CTestClass::CTestClass(CString vName, long vLong, __int64 vInt64, double vDouble)
    : m_Name(vName)
    , m_Long(vLong)
    , m_Int64(vInt64)
    , m_Double(vDouble)
	, m_Date(CTime::GetCurrentTime().GetTime())
{
}

CTestClass::~CTestClass()
{
}

CString CTestClass::GetName() const         {return m_Name;}
long    CTestClass::GetSomeLong() const     {return m_Long;}
__int64 CTestClass::GetSomeInt64() const    {return m_Int64;}
double  CTestClass::GetSomeDouble() const   {return m_Double;}
long    CTestClass::GetSomeDate() const     {return m_Date;}



void CTestClass::SetSomeLong(long v)
{
	m_Long = v;

	//Send notification to the grid. Each grid will automatically update the cell, sort and filter the row if needed.
	NotifyUpdate(FidSomeLong);
}
void CTestClass::SetSomeInt64(__int64 v)
{
	m_Int64 = v;
	
	//Send notification to the grid. Each grid will automatically update the cell, sort and filter the row if needed.
	NotifyUpdate(FidSomeInt64);
}
void CTestClass::SetSomeDouble(double v)
{
	m_Double = v;
	
	//Send notification to the grid. Each grid will automatically update the cell, sort and filter the row if needed.
	NotifyUpdate(FidSomeDouble);
}
void CTestClass::SetSomeDate(long v)
{
	m_Date = v;
	
	//Send notification to the grid. Each grid will automatically update the cell, sort and filter the row if needed.	
	NotifyUpdate(FidSomeDate);
}