/////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright 2007-2008 Dapfor
//                                                                         
// This file is part of the Dapfor software, and may only be used, modified, and distributed 
// under the terms of the Dapfor Software License, Version 1.0.
// (See accompanying file lisense.txt or open the license at www.dapfor.com/license_agreement.aspx)
// By continuing to use, modify, or distribute this file you indicate that you have read the license 
// and understand and accept it fully.
/////////////////////////////////////////////////////////////////////////////////////////////////////

#pragma once

#include <Dapfor/GUI/IControlReflector.h>

namespace Dapfor
{
namespace GUI
{

//////////////////////////////////////////////////////////////////////////
/// \brief Performs edit in place operations on any field type in CEdit control.
///
/// \version <b>2.0.0</b> Initial version
///
/// \class  CDefaultReflector DefaultReflector.h Dapfor/GUI/DefaultReflector.h
/// \file DefaultReflector.h
//////////////////////////////////////////////////////////////////////////
class DF_GUI_API CDefaultReflector : public IControlReflector
{
public:
    CDefaultReflector();            //!< Constructor
    virtual ~CDefaultReflector();   //!< Virtual destructor

public:

    /// Indicates whether a reflector matches to the specified format.
    virtual bool  Match(const Common::CFormat* format) const;
    
    /// Creates CEdit control
    virtual bool  CreateAndAttachControl(CEditInPlaceContext& context, const Common::CFormat* format, IEditInPlace::StartReason startReason);
    
    // Indicates whether CGrid can stop edit in place operation in the control
    virtual bool  CanStopEdit(const CEditInPlaceContext& context, IEditInPlace::StopReason reason) const;

    // Applies the new value, set by the user in MFC control to the specified field in the data object.
    virtual bool  Apply(CEditInPlaceContext& context, const Common::CFormat* format);

    // Detaches MFC control from CGrid and destroys it.
    virtual bool  DetachAndDestroyControl(CGrid& grid, HITEM  hItem, const CColumn* column);
    
    // Indicates that the control should be painted in CGrid painting routine. 
    virtual bool  CanDrawControl(CGridCell& cell, const CPaintContext& paintContext, UINT paintFilter);
    
    /// Does nothing
    virtual void  PostPaintCell(CGridCell& cell, const CPaintContext& paintContext, UINT paintFilter);
    
    /// Indicates that MFC control can be activated if the user clicks on the cell.
    virtual bool  CanActivateOnThumbClick(const CEditInPlaceContext& context, const Common::CFormat* format) const;

    /// Gets CEdit control.
    virtual CWnd* GetControl();
private:
    struct Impl;
    Impl*  m_Impl;
};


}


}//namespace Dapfor
