/////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright 2007-2008 Dapfor
//                                                                         
// This file is part of the Dapfor software, and may only be used, modified, and distributed 
// under the terms of the Dapfor Software License, Version 1.0.
// (See accompanying file lisense.txt or open the license at www.dapfor.com/license_agreement.aspx)
// By continuing to use, modify, or distribute this file you indicate that you have read the license 
// and understand and accept it fully.
/////////////////////////////////////////////////////////////////////////////////////////////////////

#pragma once

#include <Dapfor/GUI/Types.h>
#include <Dapfor/GUI/GUI_Export.h>
#include <Dapfor/GUI/IAutoDelete.h>

namespace Dapfor
{
namespace Common
{
class CDataObject;
}

namespace GUI
{

class CColumn ;
class CGrid;
class CGridCell;

//////////////////////////////////////////////////////////////////////////////////////////////
/// \brief Interface determining a content of the tooltip
///
/// The interface determines content is displayed in the tooltip window. GUI library presents two realizations 
/// CTooltip and CHtmlTooltip, representing information in the form of a text or a text with tags html. 
/// At displaying information in the tooltip window the grid first searches for the realization established 
/// in the grid by the CGrid::SetTooltip() function. If the programmer has not set his tooltip realization, 
/// the grid tries to get default ITooltip interface by calling ITooltipCtrl::GetDefaultToolip().
/// 
/// \class  ITooltip ITooltip.h Dapfor/GUI/ITooltip.h
/// \file ITooltip.h
//////////////////////////////////////////////////////////////////////////////////////////////
class DF_GUI_API ITooltip : public IAutoDelete
{
public:
    ///Indicates whether the tooltip can be shown on a given cell.
    virtual bool CanShow(const CGrid& grid, const CGridCell& cell) const = 0;
    
    ///Gets a text to display it in the tooltip.
    virtual TString GetText(const CGrid& grid, const CGridCell& cell) const = 0;
};

}

}//namespace Dapfor
